"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.update = update;
exports.install = install;
exports.boot = boot;

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _core = require("./core");

var _requestPromiseNative = _interopRequireDefault(require("request-promise-native"));

var _yaml = require("yaml");

var _path = require("path");

var _fsExtra = require("fs-extra");

var _nodeToolkit = require("@tech_query/node-toolkit");

var _core2 = require("create-es-pack/dist/core");

/**
 * @param {String} type - `plugin` or `theme`
 */
function update(_x) {
  return _update.apply(this, arguments);
}
/**
 * @param {String}   cwd  - Root path of a Wiki-site
 * @param {String}   type - `plugin` or `theme`
 * @param {String[]} name - Package name (Common prefix is optional)
 *
 * @return {String[]} Names of installed packages
 */


function _update() {
  _update = (0, _asyncToGenerator2.default)(function* (type) {
    const list = (0, _yaml.parse)((yield (0, _requestPromiseNative.default)(`https://raw.githubusercontent.com/hexojs/site/master/source/_data/${type}s.yml`)));
    (0, _fsExtra.ensureDirSync)((0, _path.join)(_core._base_, 'data'));
    yield (0, _fsExtra.writeJSON)((0, _path.join)(_core._base_, `data/${type}.json`), list, {
      spaces: 4
    });
    console.info(`[ Update ]  ${list.length} ${type}s`);
  });
  return _update.apply(this, arguments);
}

function install(_x2, _x3, _x4) {
  return _install.apply(this, arguments);
}

function _install() {
  _install = (0, _asyncToGenerator2.default)(function* (cwd, type, name) {
    const list = yield (0, _fsExtra.readJSON)((0, _path.join)(_core._base_, `data/${type}.json`));
    const NPM = [],
          Git = [],
          command_option = {
      stdio: 'inherit',
      cwd
    };
    list.forEach(item => {
      if (!name.find(key => RegExp(`^(hexo-(theme-)?)?${key}$`, 'i').test(item.name))) return;
      if (item.link.includes('npmjs.com/')) NPM.push(item.name);else if (type === 'plugin') NPM.push(item.link);else Git.push(item);
    });
    if (NPM[0]) yield (0, _nodeToolkit.spawn)('npm', ['install'].concat(NPM), command_option);

    if (Git[0]) {
      var _arr = Git;

      for (var _i = 0; _i < _arr.length; _i++) {
        let item = _arr[_i];
        yield (0, _core.copyFromGit)(item.link, (0, _path.join)(cwd, `themes/${item.name}/`));
      }
    }

    return NPM.concat(Git.map(item => item.name));
  });
  return _install.apply(this, arguments);
}

function addTheme(_x5, _x6, _x7) {
  return _addTheme.apply(this, arguments);
}
/**
 * Boot a directory as a WebCell project
 *
 * @param {Object}     option
 * @param {String}     [option.cwd='.']    - Current working directory
 * @param {String[]}   [option.plugins=[]]
 * @param {?String}    option.theme
 * @param {String[]}   [option.pages=[]]   - Required pages of `theme`
 * @param {String|URL} [option.remote]     - Git URL of a Remote repository
 */


function _addTheme() {
  _addTheme = (0, _asyncToGenerator2.default)(function* (cwd, name, config) {
    name = (yield install(cwd, 'theme', [name]))[0];
    if (!name) return console.error(`Theme "${name}" can't be found in Hexo offical index`);
    const path = (0, _path.join)(cwd, `themes/${name}`);

    if (!(0, _fsExtra.existsSync)(`${path}/_config.yml`)) {
      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = (0, _fsExtra.readdirSync)(path)[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          let file = _step.value;

          if (/^_config\..*yml.*/.test(file)) {
            yield (0, _fsExtra.move)(`${path}/${file}`, `${path}/_config.yml`);
            break;
          }
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return != null) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }
    }

    yield (0, _fsExtra.remove)((0, _path.join)(cwd, 'themes/landscape'));
    return config.replace(/^theme:.+/m, `theme: ${name}`);
  });
  return _addTheme.apply(this, arguments);
}

function boot() {
  return _boot.apply(this, arguments);
}

function _boot() {
  _boot = (0, _asyncToGenerator2.default)(function* ({
    cwd = '.',
    plugins = [],
    theme,
    pages = [],
    remote
  } = {}) {
    const command_option = {
      stdio: 'inherit',
      cwd
    },
          config_path = (0, _path.join)(cwd, '_config.yml');
    yield (0, _nodeToolkit.step)('Hexo framework',
    /*#__PURE__*/
    (0, _asyncToGenerator2.default)(function* () {
      yield (0, _nodeToolkit.ensureCommand)('hexo');
      yield (0, _core.copyFromGit)('https://github.com/hexojs/hexo-starter.git', cwd);
    }));
    var config, git;
    yield (0, _nodeToolkit.step)('Git repository & branch',
    /*#__PURE__*/
    (0, _asyncToGenerator2.default)(function* () {
      config = (yield (0, _fsExtra.readFile)(config_path)) + '', git = yield (0, _core2.bootGit)(cwd, remote);
      yield git.raw(['checkout', '--orphan', 'hexo']);
      config = config.replace(/\ndeploy:[\s\S]+/, `
deploy:
  type: git
  repo: ${(yield git.getRemotes(true))[0].refs.push}
  branch: master`);
    }));
    yield (0, _nodeToolkit.step)('NPM package', _core.setRoot.bind(null, cwd, git));
    yield (0, _nodeToolkit.step)('Hexo plugins',
    /*#__PURE__*/
    (0, _asyncToGenerator2.default)(function* () {
      const meta = (0, _yaml.parse)(config);
      config += '\n\n' + (0, _yaml.stringify)({
        pwa: (0, _core.setPWA)({
          name: meta.title,
          description: meta.subtitle || meta.description,
          lang: meta.language,
          start_url: meta.url,
          scope: meta.root,
          icon: {
            src: 'image/Hexo.png',
            type: 'image/png',
            sizes: '128x128'
          }
        })
      });
      yield (0, _nodeToolkit.spawn)('npm', ['install'], command_option);
      if (plugins[0]) yield install(cwd, 'plugin', plugins);
    }));
    yield (0, _nodeToolkit.step)('Hexo theme',
    /*#__PURE__*/
    (0, _asyncToGenerator2.default)(function* () {
      if (theme) config = (yield addTheme(cwd, theme, config)) || config;
      var _iteratorNormalCompletion2 = true;
      var _didIteratorError2 = false;
      var _iteratorError2 = undefined;

      try {
        for (var _iterator2 = pages[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
          let name = _step2.value;
          const file = (0, _path.join)(cwd, 'source', name, 'index.md');
          yield (0, _fsExtra.outputFile)(file, `---
type: ${name}
layout: ${name}
---\n`);
          console.info(`[ Create ]  ${file}`);
        }
      } catch (err) {
        _didIteratorError2 = true;
        _iteratorError2 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion2 && _iterator2.return != null) {
            _iterator2.return();
          }
        } finally {
          if (_didIteratorError2) {
            throw _iteratorError2;
          }
        }
      }

      yield (0, _fsExtra.outputFile)(config_path, config);
    }));
    yield (0, _nodeToolkit.step)('Git commit',
    /*#__PURE__*/
    (0, _asyncToGenerator2.default)(function* () {
      yield git.add('.');
      yield git.commit('[ Add ]  Framework of Hexo wiki');
    }));
  });
  return _boot.apply(this, arguments);
}
//# sourceMappingURL=command.js.map