"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.copyFromGit = copyFromGit;
exports.setRoot = setRoot;
exports.setPWA = setPWA;
exports._meta_ = exports._base_ = void 0;

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _nodeToolkit = require("@tech_query/node-toolkit");

var _path = require("path");

var _fsExtra = require("fs-extra");

var _core = require("create-es-pack/dist/core");

/* babel-plugin-inline-import '../package.json' */
const config = "{\n  \"name\": \"create-hexo-wiki\",\n  \"version\": \"0.7.2\",\n  \"description\": \"Wiki-site generator based on Hexo & Git\",\n  \"keywords\": [\n    \"wiki\",\n    \"website\",\n    \"generator\",\n    \"hexo\",\n    \"git\"\n  ],\n  \"author\": \"shiy2008@gmail.com\",\n  \"license\": \"AGPL-3.0\",\n  \"homepage\": \"https://tech-query.me/create-hexo-wiki/\",\n  \"repository\": {\n    \"type\": \"git\",\n    \"url\": \"git+https://github.com/TechQuery/create-hexo-wiki.git\"\n  },\n  \"bugs\": {\n    \"url\": \"https://github.com/TechQuery/create-hexo-wiki/issues\"\n  },\n  \"bin\": \"dist/index.js\",\n  \"engines\": {\n    \"node\": \"^6.3.0\"\n  },\n  \"dependencies\": {\n    \"@babel/polyfill\": \"^7.4.0\",\n    \"@babel/runtime\": \"^7.4.2\",\n    \"@tech_query/node-toolkit\": \"^0.9.3\",\n    \"commander\": \"^2.19.0\",\n    \"create-es-pack\": \"^0.4.6\",\n    \"fs-extra\": \"^7.0.1\",\n    \"request\": \"^2.88.0\",\n    \"request-promise-native\": \"^1.0.7\",\n    \"yaml\": \"^1.4.0\"\n  },\n  \"scripts\": {\n    \"lint\": \"eslint source/ --fix\",\n    \"build\": \"babel source/ -d dist/ -s\",\n    \"test\": \"npm run lint  &&  npm run build\",\n    \"prepublishOnly\": \"npm test\",\n    \"install\": \"node dist/ update\"\n  },\n  \"husky\": {\n    \"hooks\": {\n      \"pre-commit\": \"npm test  &&  git add .\"\n    }\n  },\n  \"devDependencies\": {\n    \"@babel/cli\": \"^7.2.3\",\n    \"@babel/core\": \"^7.4.0\",\n    \"@babel/plugin-transform-runtime\": \"^7.4.0\",\n    \"@babel/preset-env\": \"^7.4.2\",\n    \"babel-plugin-inline-import\": \"^3.0.0\",\n    \"eslint\": \"^5.15.3\",\n    \"husky\": \"^1.3.1\"\n  },\n  \"babel\": {\n    \"presets\": [\n      [\n        \"@babel/preset-env\",\n        {\n          \"targets\": {\n            \"node\": \"6.3.0\"\n          }\n        }\n      ]\n    ],\n    \"plugins\": [\n      [\n        \"babel-plugin-inline-import\",\n        {\n          \"extensions\": [\n            \".json\"\n          ]\n        }\n      ],\n      \"@babel/plugin-transform-runtime\"\n    ]\n  }\n}\n";
/**
 * @type {String}
 */

const _base_ = (0, _path.join)((0, _nodeToolkit.currentModulePath)(), '../../');
/**
 * @type {Object}
 */


exports._base_ = _base_;

const _meta_ = JSON.parse(config);
/**
 * @param {String|URL} URI       - Git URL
 * @param {String}     [path=''] - Copy to the path
 * @param {?Boolean}   recurse   - Recurse sub-modules
 */


exports._meta_ = _meta_;

function copyFromGit(_x) {
  return _copyFromGit.apply(this, arguments);
}
/**
 * @param {String}    path - Project root
 * @param {SimpleGit} git  - Git repository instance of `path`
 */


function _copyFromGit() {
  _copyFromGit = (0, _asyncToGenerator2.default)(function* (URI, path = '', recurse) {
    const parameter = ['clone', URI, path];
    if (recurse) parameter.splice(1, 0, '--recurse-submodules');
    yield (0, _nodeToolkit.spawn)('git', parameter, {
      stdio: 'inherit'
    });
    yield (0, _fsExtra.remove)((0, _path.join)(path, '.git/'));
    if (!recurse) yield (0, _fsExtra.remove)((0, _path.join)(path, '.gitmodules'));
  });
  return _copyFromGit.apply(this, arguments);
}

function setRoot(_x2, _x3) {
  return _setRoot.apply(this, arguments);
}
/**
 * @param {Object} [meta={}] - https://github.com/lavas-project/hexo-pwa#options
 *
 * @return {Object}
 */


function _setRoot() {
  _setRoot = (0, _asyncToGenerator2.default)(function* (path, git) {
    yield (0, _core.copyFrom)((0, _path.join)(_base_, 'template'), path);
    if (!(0, _nodeToolkit.findFile)(/ReadMe(\.(md|markdown))?/i, path)) yield _core.setReadMe.call(_meta_, path, git);
    const config = yield (0, _core.setAuthor)(path, git);
    config.meta.name = (0, _nodeToolkit.packageNameOf)(path), config.meta.version = '1.0.0';
    yield (0, _fsExtra.outputJSON)(config.path, config.meta);
  });
  return _setRoot.apply(this, arguments);
}

function setPWA({
  name,
  start_url,
  description,
  scope = '/',
  lang = 'en-US',
  dir = 'ltr',
  icon
} = {}) {
  return {
    manifest: {
      path: '/manifest.json',
      body: {
        name,
        short_name: name,
        start_url,
        description,
        scope,
        display: 'standalone',
        orientation: 'any',
        lang,
        dir,
        theme_color: 'rgba(0,0,0,0.5)',
        background_color: 'transparent',
        icons: [icon]
      }
    },
    serviceWorker: {
      path: '/sw.js',
      preload: {
        urls: [scope],
        posts: 5
      },
      opts: {
        networkTimeoutSeconds: 5
      },
      routes: [{
        pattern: '!!js/regexp /\\//',
        strategy: 'networkFirst'
      }, {
        pattern: '!!js/regexp /.*\\.(css|js|jpg|jpeg|png|gif|webp)$/',
        strategy: 'cacheFirst'
      }, {
        pattern: '!!js/regexp /google.*\\.com/',
        strategy: 'networkOnly'
      }, {
        pattern: '!!js/regexp /disqus.*\\.com/',
        strategy: 'networkOnly'
      }, {
        pattern: '!!js/regexp /cnzz\\.com/',
        strategy: 'networkOnly'
      }]
    },
    priority: 5
  };
}
//# sourceMappingURL=core.js.map